@@ -11,6 +11,7 @@ import webbrowser
 from time import sleep
 import logging
 import subprocess
+from datetime import datetime
 from operator import itemgetter
 from urllib.parse import urlparse
 import requests
@@ -60,6 +61,18 @@ def set_auth_token(auth_token: str, secrets_file=user_secrets):
         raise LoginFailureException from exc
 
 
+def set_docker_expiration_time(expires_at, secrets_file=user_secrets):
+    """Set the Auth0 token in user secrets"""
+    try:
+        toml_loader.write(
+            secrets_file,
+            {"EMBEDOPS_ECR_TOKEN_EXPIRES_AT": expires_at.timestamp()},
+            merge=True,
+        )
+    except (IOError) as exc:
+        raise LoginFailureException from exc
+
+
 def fetch_registry_token() -> str:
     """Retrieve a GitLab token for the user's group and store it"""
     user_client = get_user_client()
@@ -77,6 +90,23 @@ def fetch_registry_token() -> str:
     )
 
 
+def get_docker_expiration_time(secrets_file=user_secrets):
+    """Retrieve docker exp date"""
+    registry_token_expires_at = None
+
+    # Return false since variable is not set
+    if not os.path.exists(secrets_file):
+        return registry_token_expires_at
+
+    secrets_file_settings = Dynaconf(SETTINGS_FILES=[secrets_file])
+    try:
+        registry_token_expires_at = secrets_file_settings.EMBEDOPS_ECR_TOKEN_EXPIRES_AT
+    except AttributeError as exc:
+        raise UnauthorizedUserException from exc
+
+    return registry_token_expires_at
+
+
 def get_registry_token(secrets_file=user_secrets):
     """Retrieve the Auth0 token from user secrets"""
     if not os.path.exists(secrets_file):
@@ -89,7 +119,11 @@ def get_registry_token(secrets_file=user_secrets):
         raise UnauthorizedUserException from exc
     if not registry_token_id or not registry_token_secret:
         raise UnauthorizedUserException
-    return registry_token_id, registry_token_secret
+
+    return {
+        "registry_token_id": registry_token_id,
+        "registry_token_secret": registry_token_secret,
+    }
 
 
 def set_registry_token(
@@ -128,7 +162,11 @@ def request_authorization():  # pylint: disable=too-many-locals
     env_path = pathlib.Path(".") / ".env"
     dotenv.load_dotenv(dotenv_path=env_path)
 
-    # TODO: we'll need to set this to where the .env are stored in the application
+    # Uncomment to connect to platform in dev environment
+    # todo: Need a make setting for switching between dev & prod env ticket: EO-473
+    # client_id = "6Sm3VSVQ15B9IxTFKmwrjcPzXaH0oC1P"
+    # base_url = "https://embedops-dev.us.auth0.com/oauth"
+
     client_id = "wBgMNZyLb76QRZe3eDRsCnoBLBy4qMQh"
     base_url = "https://embedops.us.auth0.com/oauth"
 
@@ -149,11 +187,18 @@ def request_authorization():  # pylint: disable=too-many-locals
 def request_user_code(client_id, base_url):
     """Request the code to show to the user"""
     # We generate a nonce (state) that is used to protect against attackers invoking the callback
+
+    # Uncomment to connect to platform in dev environment
+    # todo: Need a make setting for switching between dev & prod env ticket: EO-473
+    # audience = "https://app-dev.embedops.com"
+    audience = "https://app.embedops.com"
+
     data = {
-        "audience": "https://app.embedops.com",
+        "audience": audience,
         "scope": "openid email profile offline_access",
         "client_id": client_id,
     }
+
     url = f"{base_url}/device/code"
 
     code_req_response = requests.post(url, data=data)
@@ -251,9 +296,13 @@ def docker_cli_login(aws_access_key_id, aws_secret_access_key):
         aws_secret_access_key=aws_secret_access_key,
         aws_session_token=aws_session_token,
     )
+
     ecr_authorization_data = ecr_client.get_authorization_token()["authorizationData"][
         0
     ]
+    # We need to save this for later to check if the token is valid when we use 'docker run ...'
+    set_docker_expiration_time(ecr_authorization_data["expiresAt"])
+
     authorization_token, registry_server = itemgetter(
         "authorizationToken", "proxyEndpoint"
     )(ecr_authorization_data)
@@ -278,12 +327,29 @@ def docker_cli_login(aws_access_key_id, aws_secret_access_key):
 def login_to_registry(secrets_file=user_secrets):
     """Log into a docker registry"""
     try:
-        registry_token_id, registry_token_secret = get_registry_token(secrets_file)
+        registry_token_data = get_registry_token(secrets_file)
+
     except UnauthorizedUserException as exc:
         raise UnauthorizedUserException from exc
-    return_code = docker_cli_login(registry_token_id, registry_token_secret)
+    return_code = docker_cli_login(
+        registry_token_data["registry_token_id"],
+        registry_token_data["registry_token_secret"],
+    )
     if return_code == 1:
         raise DockerRegistryException
     if return_code > 0:
         raise UnknownDockerException
     return return_code
+
+
+def is_registery_token_valid(secrets_file=user_secrets):
+    """Check if register token has expired"""
+    registry_token_expires_at = get_docker_expiration_time(secrets_file)
+    is_valid = False
+
+    if registry_token_expires_at:
+
+        if registry_token_expires_at > datetime.now().timestamp():
+            is_valid = True
+
+    return is_valid
