@@ -63,17 +63,21 @@ class CIRun:
         analysis_type = self._settings.analysis_type
         commit_id = self._settings.commit
         branch_name = self._settings.branch
+        job_name = self._settings.get("job_name")
 
-        return self.create(analysis_type, commit_id, branch_name)
+        if job_name is None:
+            return self.create(analysis_type, commit_id, branch_name)
+
+        return self.create(analysis_type, commit_id, branch_name, job_name)
 
     @staticmethod
-    def create(analysis_type, commit_id, branch_name):
+    def create(analysis_type, commit_id, branch_name, job_name=None):
 
         """Use the branch name, commit sha, and analysis type to create a new ciRun instance"""
 
         api_client = get_client()
         create_properties = CIRunCreateProps(
-            branch=branch_name, commit_id=commit_id, type=analysis_type
+            branch=branch_name, commit_id=commit_id, type=analysis_type, name=job_name
         )
 
         response = None
